@@ -1,11 +1,10 @@
 from PyOfficeRobot.core.WeChatType import WeChat
-from PyOfficeRobot.lib.CONST import ACT_TYPE
-from PyOfficeRobot.lib.dec.act_dec import act_info
+from PyOfficeRobot.lib.decorator_utils.instruction_url import instruction
 
 wx = WeChat()
 
-
-@act_info(ACT_TYPE.FILE)
+# @act_info(ACT_TYPE.FILE)
+@instruction
 def send_file(who, file):
     """
     发送任意类型的文件
